==> oauth_server_sso-2.0.5.tar.gz: oauth_server_sso/src/MiniorangeOAuthServerCustomer.php <==
<?php

/**
 * @file
 * Contains miniOrange Customer class.
 */

namespace Drupal\oauth_server_sso;

use Drupal\oauth_server_sso\Utilities;
use GuzzleHttp\Exception\RequestException;

class MiniorangeOAuthServerCustomer {

    public $email;
    public $phone;
    public $customerKey;
    public $transactionId;
    public $password;
    public $otpToken;
    private $defaultCustomerId;
    private $defaultCustomerApiKey;
    public $httpClient;

    /**
     * Constructor.
     */
    public function __construct($email, $phone, $password, $otp_token) {
        $this->email = $email;
        $this->phone = $phone;
        $this->password = $password;
        $this->otpToken = $otp_token;
        $this->defaultCustomerId = "16555";
        $this->defaultCustomerApiKey = "fFd2XcvTGDemZvbw1bcUesNJWEqKbbUq";
        $this->httpClient = \Drupal::httpClient();
    }

    /**
     * Check if customer exists.
     */
    public function checkCustomer() {
        if (!Utilities::isCurlInstalled()) {
            return json_encode(array(
                "status" => 'CURL_ERROR',
                "statusMessage" => '<a href="http://php.net/manual/en/curl.installation.php">PHP cURL extension</a> is not installed or disabled.',
            ));
        }

        $url = MiniorangeOAuthServerConstants::BASE_URL . '/moas/rest/customer/check-if-exists';
        $header = $this->getHeader();
        $body = ['email' => $this->email];
        $response = Utilities::callAPI($url, 'POST', $body, $header);
        
        return $response;
    }

    /**
     * Create Customer.
     */
    public function createCustomer() {
        if (!Utilities::isCurlInstalled()) {
            return json_encode(array(
                "statusCode" => 'ERROR',
                "statusMessage" => '. Please check your configuration.',
            ));
        }
        $url = MiniorangeOAuthServerConstants::BASE_URL . '/moas/rest/customer/add';
        $header = $this->getHeader();
        $body = [
            'companyName' => $_SERVER['SERVER_NAME'],
            'areaOfInterest' => 'DRUPAL 8 OAuth Server',
            'email' => $this->email,
            'phone' => $this->phone,
            'password' => $this->password,
        ];

        $response = Utilities::callAPI($url, 'POST', $body, $header);
        
        return $response;
    }

    /**
     * Get Customer Keys.
     */
    public function getCustomerKeys() {
        if (!Utilities::isCurlInstalled()) {
            return json_encode(array(
                "apiKey" => 'CURL_ERROR',
                "token" => '<a href="http://php.net/manual/en/curl.installation.php">PHP cURL extension</a> is not installed or disabled.',
            ));
        }

        $url = MiniorangeOAuthServerConstants::BASE_URL . '/moas/rest/customer/key';
        $header = $this->getHeader();
        $body = [
            'email' => $this->email,
            'password' => $this->password,
        ];
        $response = Utilities::callAPI($url, 'POST', $body, $header);

        return $response;
    }

    /**
     * Send OTP.
     */
    public function sendOtp() {
        if (!Utilities::isCurlInstalled()) {
            return json_encode(array(
                "status" => 'CURL_ERROR',
                "statusMessage" => '<a href="http://php.net/manual/en/curl.installation.php">PHP cURL extension</a> is not installed or disabled.',
            ));
        }

        $customer_key = $this->defaultCustomerId;
        $username = \Drupal::config('oauth_server_sso.settings')->get('oauth_server_sso_customer_admin_email');

        $url = MiniorangeOAuthServerConstants::BASE_URL . '/moas/api/auth/challenge';
        $header = $this->getHeader(true);
        $body = [
            'customerKey' => $customer_key,
            'email' => $username,
            'authType' => 'EMAIL',
        ];

        $response = Utilities::callAPI($url, 'POST', $body, $header);
        
        return $response;
    }

    /**
     * Validate OTP.
     */
    public function validateOtp($transaction_id) {
        if (!Utilities::isCurlInstalled()) {
            return json_encode(array(
                "status" => 'CURL_ERROR',
                "statusMessage" => '<a href="http://php.net/manual/en/curl.installation.php">PHP cURL extension</a> is not installed or disabled.',
            ));
        }

        $url = MiniorangeOAuthServerConstants::BASE_URL . '/moas/api/auth/validate';
        
        $header = $this->getHeader(true);
        $body = [
            'txId' => $transaction_id,
            'token' => $this->otpToken,
        ];
        $response = Utilities::callAPI($url, 'POST', $body, $header);
        
        return $response;
    }

    public function getHeader($addExtendedHeader = FALSE){

        $header = [
            'Content-Type'=>'application/json', 'charset'=>'UTF - 8',
            'Authorization'=> 'Basic',
        ];

        if($addExtendedHeader){
            /* Current time in milliseconds since midnight, January 1, 1970 UTC. */
            $current_time_in_millis = $this->getTimeStamp();

            /* Creating the Hash using SHA-512 algorithm */
            $string_to_hash = $this->defaultCustomerId .$current_time_in_millis . $this->defaultCustomerApiKey;
            $hashValue = hash("sha512", $string_to_hash);
            $timestamp_header = number_format($current_time_in_millis, 0, '', '' );
            $header=array_merge($header,array("Customer-Key"=>$this->defaultCustomerId,
                "Timestamp"=>$timestamp_header, "Authorization"=>$hashValue));
        }
        return $header;
    }

    public function getTimeStamp()
    {
        $url = MiniorangeOAuthServerConstants::BASE_URL.'/moas/rest/mobile/get-timestamp';
        $body = [];
        $currentTimeInMillis = Utilities::callAPI($url, 'POST', $body);

        if (empty($currentTimeInMillis)) {
            $currentTimeInMillis = round(microtime(true) * 1000);
            $currentTimeInMillis = number_format($currentTimeInMillis, 0, '', '');
        }
        
        return $currentTimeInMillis;
    }
}

==> oauth_server_sso-2.0.9.tar.gz: oauth_server_sso/src/MiniorangeOAuthServerCustomer.php <==
<?php

/**
 * @file
 * Contains miniOrange Customer class.
 */

namespace Drupal\oauth_server_sso;

use Drupal\oauth_server_sso\Utilities;

class MiniorangeOAuthServerCustomer {
    public $email;
    public $phone;
    public $customerKey;
    public $transactionId;
    public $password;
    public $otpToken;
    private $defaultCustomerId;
    private $defaultCustomerApiKey;
    public $httpClient;

    /**
     * Constructor.
     */
    public function __construct($email, $phone, $password, $otp_token) {
        $this->email = $email;
        $this->phone = $phone;
        $this->password = $password;
        $this->otpToken = $otp_token;
        $this->defaultCustomerId = "16555";
        $this->defaultCustomerApiKey = "fFd2XcvTGDemZvbw1bcUesNJWEqKbbUq";
        $this->httpClient = \Drupal::httpClient();
    }

    /**
     * Check if customer exists.
     */
    public function checkCustomer() {
        if (!Utilities::isCurlInstalled()) {
            return json_encode(array(
                "status" => 'CURL_ERROR',
                "statusMessage" => '<a href="http://php.net/manual/en/curl.installation.php">PHP cURL extension</a> is not installed or disabled.',
            ));
        }

        $url = MiniorangeOAuthServerConstants::BASE_URL . '/moas/rest/customer/check-if-exists';
        $header = $this->getHeader();
        $body = ['email' => $this->email];
        $response = Utilities::callAPI($url, 'POST', $body, $header);

        return $response;
    }

    /**
     * Create Customer.
     */
    public function createCustomer() {
        if (!Utilities::isCurlInstalled()) {
            return json_encode(array(
                "statusCode" => 'ERROR',
                "statusMessage" => '. Please check your configuration.',
            ));
        }
        $url = MiniorangeOAuthServerConstants::BASE_URL . '/moas/rest/customer/add';
        $header = $this->getHeader();
        $body = [
            'companyName' => $_SERVER['SERVER_NAME'],
            'areaOfInterest' => 'DRUPAL 8 OAuth Server',
            'email' => $this->email,
            'phone' => $this->phone,
            'password' => $this->password,
        ];

        $response = Utilities::callAPI($url, 'POST', $body, $header);

        return $response;
    }

    /**
     * Get Customer Keys.
     */
    public function getCustomerKeys() {
        if (!Utilities::isCurlInstalled()) {
            return json_encode(array(
                "apiKey" => 'CURL_ERROR',
                "token" => '<a href="http://php.net/manual/en/curl.installation.php">PHP cURL extension</a> is not installed or disabled.',
            ));
        }

        $url = MiniorangeOAuthServerConstants::BASE_URL . '/moas/rest/customer/key';
        $header = $this->getHeader();
        $body = [
            'email' => $this->email,
            'password' => $this->password,
        ];
        $response = Utilities::callAPI($url, 'POST', $body, $header);

        return $response;
    }

    /**
     * Send OTP.
     */
    public function sendOtp() {
        if (!Utilities::isCurlInstalled()) {
            return json_encode(array(
                "status" => 'CURL_ERROR',
                "statusMessage" => '<a href="http://php.net/manual/en/curl.installation.php">PHP cURL extension</a> is not installed or disabled.',
            ));
        }

        $customer_key = $this->defaultCustomerId;
        $username = \Drupal::config('oauth_server_sso.settings')->get('oauth_server_sso_customer_admin_email');

        $url = MiniorangeOAuthServerConstants::BASE_URL . '/moas/api/auth/challenge';
        $header = $this->getHeader(true);
        $body = [
            'customerKey' => $customer_key,
            'email' => $username,
            'authType' => 'EMAIL',
        ];

        $response = Utilities::callAPI($url, 'POST', $body, $header);

        return $response;
    }

    /**
     * Validate OTP.
     */
    public function validateOtp($transaction_id) {
        if (!Utilities::isCurlInstalled()) {
            return json_encode(array(
                "status" => 'CURL_ERROR',
                "statusMessage" => '<a href="http://php.net/manual/en/curl.installation.php">PHP cURL extension</a> is not installed or disabled.',
            ));
        }

        $url = MiniorangeOAuthServerConstants::BASE_URL . '/moas/api/auth/validate';

        $header = $this->getHeader(true);
        $body = [
            'txId' => $transaction_id,
            'token' => $this->otpToken,
        ];
        $response = Utilities::callAPI($url, 'POST', $body, $header);

        return $response;
    }

    public function getHeader($addExtendedHeader = FALSE){
        $header = [
            'Content-Type'=>'application/json', 'charset'=>'UTF - 8',
            'Authorization'=> 'Basic',
        ];
        if($addExtendedHeader){
            /* Current time in milliseconds since midnight, January 1, 1970 UTC. */
            $current_time_in_millis = $this->getTimeStamp();

            /* Creating the Hash using SHA-512 algorithm */
            $string_to_hash = $this->defaultCustomerId .$current_time_in_millis . $this->defaultCustomerApiKey;
            $hashValue = hash("sha512", $string_to_hash);
            $timestamp_header = number_format($current_time_in_millis, 0, '', '' );
            $header=array_merge($header,array("Customer-Key"=>$this->defaultCustomerId,
                "Timestamp"=>$timestamp_header, "Authorization"=>$hashValue));
        }
        return $header;
    }

    public function getTimeStamp(){
        $url = MiniorangeOAuthServerConstants::BASE_URL.'/moas/rest/mobile/get-timestamp';
        $body = [];
        $currentTimeInMillis = Utilities::callAPI($url, 'POST', $body);

        if (empty($currentTimeInMillis)) {
            $currentTimeInMillis = round(microtime(true) * 1000);
            $currentTimeInMillis = number_format($currentTimeInMillis, 0, '', '');
        }
        return $currentTimeInMillis;
    }
}
